.. pymrio documentation master file, created by KST 20140530

pymrio - multi regional input output analysis in python
=======================================================

Contents:

.. toctree::
   :maxdepth: 3

   intro
   installation
   terminology
   math
   Automatic MRIO download <notebooks/autodownload>
   notebooks/metadata
   handling
   development
   changelog
   api_references



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

